@@ -12,9 +12,9 @@
 # </@LICENSE>
 
 # Version control:
-# $Revision: 169 $
+# $Revision: 218 $
 # $Author: merijn $
-# $Date: 2016-09-09 14:36:13 +0200 (Fri, 09 Sep 2016) $
+# $Date: 2017-03-01 11:11:37 +0100 (Wed, 01 Mar 2017) $
 
 =head1 NAME
 
@@ -76,7 +76,7 @@ use Archive::Zip qw( :ERROR_CODES :CONSTANTS );
 use IO::String;
 
 use base qw(Mail::SpamAssassin::Plugin);
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 our $LOG_FACILITY = 'AttachmentPresent';
 
@@ -142,6 +142,21 @@ sub _build_attachment_tree {
       $attachment_filename =~ s/\s+$//;
       l('_build_attachment_tree->part: part has name '.$attachment_filename);
       push(@{$pms->{'attachment_data'}->{'files'}},$attachment_filename);
+    }else{
+      # fallback check in Content-Disposition header
+      # some (spam) has Content-Disposition with filename but no filename in Content-Type,
+      # but mail clients will still display the attachment.
+      my $cdp = $part->get_header('content-disposition') || '';
+      # Content-* headers and thus the filename in the Content-Type header is not decoded :(
+      $cdp=Encode::decode('MIME-Header', $cdp);
+      # $cdp might contain wide characters now
+      if($cdp =~ m/name\s*=\s*"?([^";]*)"?/is){
+        $attachment_filename=$1;
+        # lets be sure and remove any whitespace from the end
+        $attachment_filename =~ s/\s+$//;
+        l('_build_attachment_tree->part: part has name (in Content-Disposition) '.$attachment_filename);
+        push(@{$pms->{'attachment_data'}->{'files'}},$attachment_filename);
+      }
     }
     
     # now process attachments
